part1

Function part1 

pub fn part1(input: &[Node]) -> usize
No need to actually check node pairs because only the empty node can receive data, and all but the wall nodes can pair with the empty node but not each other.